@@ -8,7 +8,7 @@ static const GdkPixdata slide = {
   800, /* width */
   52, /* height */
   /* pixel_data: */
-  "\3\0\0\0\27\0\0\0\17\1\1\1\2\341\0\0\0\0\3\0\0\0/\0\0\0\36\1\1\1\5\341"
+  (guchar *)"\3\0\0\0\27\0\0\0\17\1\1\1\2\341\0\0\0\0\3\0\0\0/\0\0\0\36\1\1\1\5\341"
   "\0\0\0\0\3\0\0\0F\0\0\0-\1\1\1\10\341\0\0\0\0\3\0\0\0^\0\0\0<\1\1\1\13"
   "\341\0\0\0\0\3\0\0\0u\0\0\0K\1\1\1\16\341\0\0\0\0\3\0\0\0\215\0\0\0Z"
   "\1\1\1\21\341\0\0\0\0\3\0\0\0\244\0\0\0i\1\1\1\24\341\0\0\0\0\3\0\0\0"
