@@ -1,6 +1,6 @@
-/* $Id: simple.c,v 1.7 2004/11/01 16:10:55 benny Exp $ */
+/* $Id$ */
 /*-
- * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
+ * Copyright (c) 2003-2007 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,6 +23,10 @@
 #include <config.h>
 #endif
 
+#ifdef XFCE_DISABLE_DEPRECATED
+#undef XFCE_DISABLE_DEPRECATED
+#endif
+
 #include <X11/Xlib.h>
 
 #include <gdk-pixbuf/gdk-pixdata.h>
@@ -88,8 +92,9 @@ simple_setup (XfsmSplashEngine *engine,
   PangoContext         *context;
   GdkWindowAttr         attr;
   GdkRectangle          geo;
-  const gchar          *font;
-  const gchar          *path;
+  gchar                *color;
+  gchar                *font;
+  gchar                *path;
   GdkWindow            *root;
   GdkPixbuf            *logo = NULL;
   GdkCursor            *cursor;
@@ -101,10 +106,14 @@ simple_setup (XfsmSplashEngine *engine,
   simple = (Simple *) engine->user_data;
 
   /* load settings */
-  gdk_color_parse (xfsm_splash_rc_read_entry (rc, "BgColor", DEFAULT_BGCOLOR),
-                   &simple->bgcolor);
-  gdk_color_parse (xfsm_splash_rc_read_entry (rc, "FgColor", DEFAULT_FGCOLOR),
-                   &simple->fgcolor);
+  color = xfsm_splash_rc_read_entry (rc, "BgColor", DEFAULT_BGCOLOR);
+  gdk_color_parse (color, &simple->bgcolor);
+  g_free (color);
+
+  color = xfsm_splash_rc_read_entry (rc, "FgColor", DEFAULT_FGCOLOR);
+  gdk_color_parse (color, &simple->fgcolor);
+  g_free (color);
+
   font = xfsm_splash_rc_read_entry (rc, "Font", DEFAULT_FONT);
   path = xfsm_splash_rc_read_entry (rc, "Image", NULL);
 
@@ -186,6 +195,8 @@ simple_setup (XfsmSplashEngine *engine,
   gdk_window_show (simple->window);
 
   /* cleanup */
+  g_free (font);
+  g_free (path);
   pango_font_description_free (description);
   pango_font_metrics_unref (metrics);
   gdk_cursor_unref (cursor);
@@ -304,44 +315,14 @@ config_toggled (GtkWidget *button, GtkWidget *widget)
 }
 
 
-static void
-config_browse (GtkWidget *button, GtkWidget *entry)
-{
-  const gchar *filename;
-  GtkWidget   *chooser;
-  GtkWidget   *toplevel;
-
-  toplevel = gtk_widget_get_toplevel (button);
-  chooser = xfce_file_chooser_new (_("Choose image..."),
-                                   GTK_WINDOW (toplevel),
-                                   XFCE_FILE_CHOOSER_ACTION_OPEN,
-                                   GTK_STOCK_OPEN,
-                                   GTK_RESPONSE_OK,
-                                   GTK_STOCK_CANCEL,
-                                   GTK_RESPONSE_CANCEL,
-                                   NULL);
-
-  filename = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (filename != NULL)
-    xfce_file_chooser_set_filename (XFCE_FILE_CHOOSER (chooser), filename);
-  xfce_file_chooser_set_select_multiple (XFCE_FILE_CHOOSER (chooser), FALSE);
-
-  if (gtk_dialog_run (GTK_DIALOG (chooser)) == GTK_RESPONSE_OK)
-    {
-      filename = xfce_file_chooser_get_filename (XFCE_FILE_CHOOSER (chooser));
-      gtk_entry_set_text (GTK_ENTRY (entry), filename);
-    }
-
-  gtk_widget_destroy (chooser);
-}
-
-
 static void
 config_configure (XfsmSplashConfig *config,
                   GtkWidget        *parent)
 {
-  const gchar *font;
-  const gchar *path;
+  gchar       *font;
+  gchar       *path;
+  gchar       *path_locale = NULL;
+  gchar       *colorstr;
   GtkWidget   *dialog;
   GtkWidget   *frame;
   GtkWidget   *btn_font;
@@ -350,9 +331,9 @@ config_configure (XfsmSplashConfig *config,
   GtkWidget   *sel_bg;
   GtkWidget   *sel_fg;
   GtkWidget   *checkbox;
-  GtkWidget   *entry;
-  GtkWidget   *image;
+  GtkWidget   *vbox;
   GtkWidget   *button;
+  GtkFileFilter *filter;
   GdkColor     color;
   GtkBox      *dbox;
   gchar        buffer[32];
@@ -374,6 +355,7 @@ config_configure (XfsmSplashConfig *config,
 
   font = xfsm_splash_rc_read_entry (config->rc, "Font", DEFAULT_FONT);
   btn_font = gtk_font_button_new_with_font (font);
+  g_free (font);
   xfce_framebox_add (XFCE_FRAMEBOX (frame), btn_font);
   gtk_widget_show (btn_font);
 
@@ -390,8 +372,9 @@ config_configure (XfsmSplashConfig *config,
                     GTK_FILL, GTK_FILL, 0, 0);
   gtk_widget_show (label);
 
-  gdk_color_parse (xfsm_splash_rc_read_entry (config->rc, "BgColor",
-                                              DEFAULT_BGCOLOR), &color);
+  colorstr = xfsm_splash_rc_read_entry (config->rc, "BgColor", DEFAULT_BGCOLOR);
+  gdk_color_parse (colorstr, &color);
+  g_free (colorstr);
   sel_bg = xfce_color_button_new_with_color (&color);
   gtk_table_attach (GTK_TABLE (table), sel_bg, 1, 2, 0, 1,
                     GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
@@ -402,8 +385,9 @@ config_configure (XfsmSplashConfig *config,
                     GTK_FILL, GTK_FILL, 0, 0);
   gtk_widget_show (label);
 
-  gdk_color_parse (xfsm_splash_rc_read_entry (config->rc, "FgColor",
-                                              DEFAULT_FGCOLOR), &color);
+  colorstr = xfsm_splash_rc_read_entry (config->rc, "FgColor", DEFAULT_FGCOLOR);
+  gdk_color_parse (colorstr, &color);
+  g_free (colorstr);
   sel_fg = xfce_color_button_new_with_color (&color);
   gtk_table_attach (GTK_TABLE (table), sel_fg, 1, 2, 1, 2,
                     GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
@@ -413,55 +397,56 @@ config_configure (XfsmSplashConfig *config,
   gtk_box_pack_start (dbox, frame, FALSE, FALSE, 6);
   gtk_widget_show (frame);
 
-  table = gtk_table_new (2, 2, FALSE);
-  xfce_framebox_add (XFCE_FRAMEBOX (frame), table);
-  gtk_widget_show (table);
+  vbox = gtk_vbox_new (FALSE, 6);
+  xfce_framebox_add (XFCE_FRAMEBOX (frame), vbox);
+  gtk_widget_show (vbox);
 
   checkbox = gtk_check_button_new_with_label (_("Use custom image"));
-  gtk_table_attach (GTK_TABLE (table), checkbox, 0, 2, 0, 1,
-                    GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), checkbox, FALSE, FALSE, 0);
   gtk_widget_show (checkbox);
 
-  entry = gtk_entry_new ();
-  gtk_table_attach (GTK_TABLE (table), entry, 0, 1, 1, 2,
-                    GTK_FILL, GTK_FILL, 0, 0);
-  gtk_widget_show (entry);
-
-  image = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_BUTTON);
-  gtk_widget_show (image);
-  button = gtk_button_new ();
-  gtk_container_add (GTK_CONTAINER (button), image);
-  gtk_table_attach (GTK_TABLE (table), button, 1, 2, 1, 2,
-                    GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+  button = gtk_file_chooser_button_new (_("Choose image..."),
+                                        GTK_FILE_CHOOSER_ACTION_OPEN);
+  gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
   gtk_widget_show (button);
 
+  filter = gtk_file_filter_new ();
+  gtk_file_filter_set_name (filter, _("Images"));
+  gtk_file_filter_add_pixbuf_formats (filter);
+  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (button), filter);
+
+  filter = gtk_file_filter_new ();
+  gtk_file_filter_set_name (filter, _("All files"));
+  gtk_file_filter_add_pattern (filter, "*");
+  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (button), filter);
+
+  gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (button), 0);
+
   path = xfsm_splash_rc_read_entry (config->rc, "Image", NULL);
-  if (path == NULL || !g_file_test (path, G_FILE_TEST_IS_REGULAR))
+  if (path != NULL)
+    path_locale = g_filename_from_utf8 (path, -1, NULL, NULL, NULL);
+  g_free (path);
+  if (path_locale == NULL || !g_file_test (path_locale, G_FILE_TEST_IS_REGULAR))
     {
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), FALSE);
-      gtk_widget_set_sensitive (entry, FALSE);
       gtk_widget_set_sensitive (button, FALSE);
     }
   else
     {
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbox), TRUE);
-      gtk_widget_set_sensitive (entry, TRUE);
       gtk_widget_set_sensitive (button, TRUE);
-      gtk_entry_set_text (GTK_ENTRY (entry), path);
+      gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (button), path_locale);
     }
-  g_signal_connect (G_OBJECT (checkbox), "toggled",
-                    G_CALLBACK (config_toggled), entry);
+  g_free (path_locale);
   g_signal_connect (G_OBJECT (checkbox), "toggled",
                     G_CALLBACK (config_toggled), button);
-  g_signal_connect (G_OBJECT (button), "clicked",
-                    G_CALLBACK (config_browse), entry);
 
   /* run the dialog */
   gtk_dialog_run (GTK_DIALOG (dialog));
 
   /* store settings */
-  font = gtk_font_button_get_font_name (GTK_FONT_BUTTON (btn_font));
-  xfsm_splash_rc_write_entry (config->rc, "Font", font);
+  xfsm_splash_rc_write_entry (config->rc, "Font",
+                              gtk_font_button_get_font_name (GTK_FONT_BUTTON (btn_font)));
 
   xfce_color_button_get_color (XFCE_COLOR_BUTTON (sel_bg), &color);
   g_snprintf (buffer, 32, "#%02x%02x%02x",
@@ -477,16 +462,19 @@ config_configure (XfsmSplashConfig *config,
               (unsigned) color.blue >> 8);
   xfsm_splash_rc_write_entry (config->rc, "FgColor", buffer);
 
-  path = gtk_entry_get_text (GTK_ENTRY (entry));
+  path_locale = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (button));
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbox))
-      && path != NULL && g_file_test (path, G_FILE_TEST_IS_REGULAR))
+      && path_locale != NULL && g_file_test (path_locale, G_FILE_TEST_IS_REGULAR))
     {
+      path = g_filename_to_utf8 (path_locale, -1, NULL, NULL, NULL);
       xfsm_splash_rc_write_entry (config->rc, "Image", path);
+      g_free (path);
     }
   else
     {
       xfsm_splash_rc_write_entry (config->rc, "Image", "");
     }
+  g_free (path_locale);
   
   gtk_widget_destroy (dialog);
 }
@@ -502,8 +490,8 @@ config_preview (XfsmSplashConfig *config)
 G_MODULE_EXPORT void
 config_init (XfsmSplashConfig *config)
 {
-  config->name        = g_strdup ("Simple");
-  config->description = g_strdup ("Simple Splash Engine");
+  config->name        = g_strdup (_("Simple"));
+  config->description = g_strdup (_("Simple Splash Engine"));
   config->version     = g_strdup (VERSION);
   config->author      = g_strdup ("Benedikt Meurer");
   config->homepage    = g_strdup ("http://www.xfce.org/");
