@@ -1,4 +1,4 @@
-/* $Id: sm-layer.h 20833 2006-04-09 18:08:17Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -22,8 +22,13 @@
 #ifndef __SM_LAYER_H__
 #define __SM_LAYER_H__
 
+#include <xfconf/xfconf.h>
 #include <libxfce4util/libxfce4util.h>
 
-void sm_init (XfceRc *rc, gboolean disable_tcp);
+#include "xfsm-manager.h"
+
+void sm_init (XfconfChannel *channel,
+              gboolean       disable_tcp,
+              XfsmManager   *manager);
 
 #endif /* !__SM_LAYER_H__ */
