@@ -1,4 +1,4 @@
-/* $Id: xfsm-shutdown-helper.c 29429 2009-02-02 06:11:53Z kelnos $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -554,7 +554,13 @@ xfsm_shutdown_helper_send_command (XfsmShutdownHelper *helper,
 
       if (ferror (helper->outfile))
         {
-          if (error && errno != EINTR)
+          if (errno == EINTR)
+            {
+              /* probably succeeded but the helper got killed */
+              return TRUE;
+            }
+
+          if (error)
             {
               g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (errno),
                            _("Error sending command to shutdown helper: %s"),
@@ -565,7 +571,13 @@ xfsm_shutdown_helper_send_command (XfsmShutdownHelper *helper,
 
       if (fgets (response, 256, helper->infile) == NULL)
         {
-          if (error && errno != EINTR)
+          if (errno == EINTR)
+            {
+              /* probably succeeded but the helper got killed */
+              return TRUE;
+            }
+
+          if (error)
             {
               g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (errno),
                            _("Error receiving response from shutdown helper: %s"),
